1.17.5 — Rucio 1.2 documentation

# 1.17.5

## General

### Enhancements

- Documentation: rucio documentation fixes #1310
- Infrastructure: cx_oracle version in containers should be fixed to 6.3.1 #1318
- Infrastructure: Docker image build of rucio demo fails #1329
- Infrastructure: Incorrect configuration of rucio demo? #1334

### Bugs

- Rebalancing: Fix activity in BB8 #1361
- Testing: Reset db tables script fails silently #1317 <https://github.com/rucio/rucio/issues/1317>

## Clients

### Bugs

- RSE Manager: Deleting left-overs of first attempt of upload by correct protocol #1346
- Release management: Downgrade to older setuptools version as 39.0.1 is not py2.6 compatible #1355